@@ -2,7 +2,7 @@ summary.etasclass<-function(object,...){
 x=object
 cat("Call:","\n","\n")
 print(x$this.call)
-cat("\n","\n","\n")
+cat("\n","\n")
 cat(x$description,"\n")
 cat("Execution started:                 ",format(x$time.start),"\n")
 cat("Elapsed time of execution (hours)  ",as.numeric(x$time.elapsed,units="hours"),"\n")
@@ -20,10 +20,14 @@ cat("flp                                ",x$flp,"\n")
 cat("sequence of AIC values for each iteration","\n")
 cat(x$AIC.iter,"\n","\n")
 }
+cat("final AIC value","\n")
+cat(x$AIC,"\n","\n")
 cat("-------------------------------------------------------","\n","\n")
 
+cat("formula for covariates of the triggered components:","\n")
+print(x$formula1)
 cat("ETAS Parameters:","\n")
-ris=cbind(x$params,x$sqm)
+ris=cbind(x$params.MLtot,x$sqm)
 colnames(ris)=c("      Estimates","      std.err.")
 print(round(ris,6))
 cat("-------------------------------------------------------","\n")
